| coglasso | R Documentation |
coglasso() estimates multiple multi-omics networks with the algorithm
collaborative graphical lasso, one for each combination of input values for
the hyperparameters \lambda_w, \lambda_b and c.
coglasso(
data,
pX,
lambda_w = NULL,
lambda_b = NULL,
c = NULL,
nlambda_w = NULL,
nlambda_b = NULL,
nc = NULL,
lambda_w_max = NULL,
lambda_b_max = NULL,
c_max = NULL,
lambda_w_min_ratio = NULL,
lambda_b_min_ratio = NULL,
c_min_ratio = NULL,
cov_output = FALSE,
verbose = TRUE
)
data |
The input multi-omics data set. Rows should be samples, columns
should be variables. Variables should be grouped by their assay (i.e.
transcripts first, then metabolites). |
pX |
The number of variables of the first data set (i.e. the number of
transcripts). |
lambda_w |
A vector of values for the parameter |
lambda_b |
A vector of values for the parameter |
c |
A vector of values for the parameter |
nlambda_w |
The number of requested |
nlambda_b |
The number of requested |
nc |
The number of requested |
lambda_w_max |
The greatest generated |
lambda_b_max |
The greatest generated |
c_max |
The greatest generated |
lambda_w_min_ratio |
The ratio of the smallest generated |
lambda_b_min_ratio |
The ratio of the smallest generated |
c_min_ratio |
The ratio of the smallest generated |
cov_output |
Add the estimated variance-covariance matrix to the output. |
verbose |
Print information regarding current |
coglasso() returns a list containing several elements:
loglik is a numerical vector containing the log likelihoods of all
the estimated networks.
density is a numerical vector containing a measure of the density of all
the estimated networks.
df is an integer vector containing the degrees of freedom of all the
estimated networks.
convergence is a binary vector containing whether a network was
successfully estimated for the given combination of hyperparameters or not.
path is a list containing the adjacency matrices of all the estimated
networks.
icov is a list containing the inverse covariance matrices of all the
estimated networks.
nexploded is the number of combinations of hyperparameters for which
coglasso() failed to converge.
data is the input multi-omics data set.
hpars is the ordered table of all the combinations of hyperparameters
given as input to coglasso(), with \alpha(\lambda_w+\lambda_b)
being the key to sort rows.
lambda_w is a numerical vector with all the \lambda_w values coglasso()
used.
lambda_b is a numerical vector with all the \lambda_b values coglasso()
used.
c is a numerical vector with all the c values coglasso()
used.
pX is the number of variables of the first data set.
cov optional, returned when cov_output is TRUE, is a list containing
the variance-covariance matrices of all the estimated networks.
# Typical usage: set the number of hyperparameters to explore
cg <- coglasso(multi_omics_sd_micro, pX = 4, nlambda_w = 3, nlambda_b = 3, nc = 3, verbose = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.