| get_pcor | R Documentation |
coglasso partial correlation matrixget_pcor() extracts the selected partial correlation matrix from a
select_coglasso object, or a different specific one from either a
select_coglasso or a coglasso object when specifying the optional
parameters.
get_pcor(sel_cg_obj, index_c = NULL, index_lw = NULL, index_lb = NULL)
sel_cg_obj |
The object of |
index_c |
The index of the |
index_lw |
The index of the |
index_lb |
The index of the |
If the input is a coglasso object, it is necessary to specify all the
indexes to extract the chosen partial correlation matrix.
If the input is a select_coglasso object, it extracts by default the
selected partial correlation matrix. If the selection method was "ebic", and
you want to extract a different partial correlation matrix than the selected
one, specify all indexes. Otherwise, if the objective is to extract the
optimal partial correlation matrix for a specific c value different
than the selected one, set index_c to your chosen one. Also here it is
possible to extract a specific non-optimal partial correlation matrix by
setting all the indexes to the chosen ones.
get_pcor() returns the selected partial correlation matrix.
sel_cg <- bs(multi_omics_sd_micro, p = c(4, 2), nlambda_w = 3, nlambda_b = 3,
nc = 3, verbose = FALSE)
sel_pcor <- get_pcor(sel_cg)
print(sel_pcor)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.